@@ -1,11 +1,9 @@
 //! Alacritty - The GPU Enhanced Terminal.
 
 #![warn(rust_2018_idioms, future_incompatible)]
-#![deny(clippy::all, clippy::if_not_else, clippy::enum_glob_use, clippy::wrong_pub_self_convention)]
+#![deny(clippy::all, clippy::if_not_else, clippy::enum_glob_use)]
 #![cfg_attr(feature = "cargo-clippy", deny(warnings))]
 
-pub mod ansi;
-pub mod config;
 pub mod event;
 pub mod event_loop;
 pub mod grid;
@@ -19,3 +17,4 @@ pub mod vi_mode;
 
 pub use crate::grid::Grid;
 pub use crate::term::Term;
+pub use vte;
